@@ -143,7 +143,7 @@ dimFree(dimPTR this)
     Free(this);
 }
 
-size_t
+int
 count_DmHalf_pars( dimPTR dd, longint *pdClass )
 {
     int i, result;
@@ -158,7 +158,7 @@ count_DmHalf_pars( dimPTR dd, longint *pdClass )
 	case 3: result += 2;
 	}
     }
-    return (size_t) result;
+    return result;
 }
 
 double *
@@ -499,7 +499,7 @@ finite_diff_Hess( double (*func)(double*), double *pars, int npar,
     return;
 }
 
-void				/* For optif0 or optif9 */
+void				/* For optif9 */
 mixed_fcn(longint n, double *pars, double *g, void *state)
 {
     statePTR st = (statePTR) state;
@@ -513,7 +513,7 @@ mixed_fcn(longint n, double *pars, double *g, void *state)
     Free(Delta); Free(zxcopy);
 }
 
-void				/* For optif0 or optif9 */
+void				/* For optif9 */
 mixed_grad(longint n, double *pars, double *g, void *state)
 {
     statePTR st = (statePTR) state;
